@@ -56,6 +56,7 @@ AppearanceManager::AppearanceManager(AppearanceProperty *prop, QObject *parent)
     , m_customTheme(new CustomTheme())
     , m_globalThemeUpdating(false)
     , m_wallpaperConfig({})
+    , m_opacityTriggerTimer(new QTimer(this))
 {
     if (QGSettings::isSchemaInstalled(XSETTINGSSCHEMA)) {
         m_xSetting = QSharedPointer<QGSettings>(new QGSettings(XSETTINGSSCHEMA));
@@ -95,6 +96,10 @@ bool AppearanceManager::init()
         qWarning() << "xcb_randr_query_version_reply faile";
         return false;
     }
+    m_opacityTriggerTimer->setSingleShot(true);
+    m_opacityTriggerTimer->setInterval(200);
+
+    connect(m_opacityTriggerTimer, &QTimer::timeout, this, &AppearanceManager::onOpacityTriggerTimeout);
 
     connect(m_dbusProxy.get(), &AppearanceDBusProxy::workspaceCountChanged, this, &AppearanceManager::handleWmWorkspaceCountChanged);
     connect(m_dbusProxy.get(), &AppearanceDBusProxy::SetScaleFactorStarted, this, &AppearanceManager::handleSetScaleFactorStarted);
@@ -319,7 +324,6 @@ void AppearanceManager::handleSettingDConfigChange(QString key)
             }
             bSuccess = doSetGlobalTheme(value);
             if (bSuccess) {
-                setQtActiveColor("");
                 setGlobalTheme(value);
             }
         } else if (key == GSKEYGTKTHEME) {
@@ -597,21 +601,30 @@ void AppearanceManager::setWindowRadius(int value)
 
 void AppearanceManager::setOpacity(double value)
 {
-    if (m_settingDconfig.isValid() && !qFuzzyCompare(value, m_property->opacity)) {
-        m_settingDconfig.setValue(GSKEYOPACITY, value);
-        m_property->opacity = value;
-        updateCustomTheme(TYPEWINDOWOPACITY, QString::number(value));
+    m_tmpOpacity = value;
+    if (!m_opacityTriggerTimer->isActive()) {
+        m_opacityTriggerTimer->start();
+    }
+}
+
+void AppearanceManager::onOpacityTriggerTimeout()
+{
+    if (m_settingDconfig.isValid() && !qFuzzyCompare(m_tmpOpacity, m_property->opacity)) {
+        m_settingDconfig.setValue(GSKEYOPACITY, m_tmpOpacity);
+        m_property->opacity = m_tmpOpacity;
+        updateCustomTheme(TYPEWINDOWOPACITY, QString::number(m_tmpOpacity));
     }
 }
 
 void AppearanceManager::setQtActiveColor(const QString &value)
 {
-    if (value != m_property->qtActiveColor && m_xSetting) {
-        QStringList colors = m_settingDconfig.value(DACTIVECOLORS).toString().split(',');
-        QString result = m_settingDconfig.value(GSKEYGLOBALTHEME).toString().endsWith("dark") ?
-            colors.value(1) : colors.value(0);
+    Q_UNUSED(value)
+    QString activeColors = m_settingDconfig.value(DACTIVECOLORS).toString();
+    QStringList colors = activeColors.split(',');
+    QString result = m_currentGlobalTheme.endsWith("dark") ? colors.value(1) : colors.value(0);
+    if (QColor(result) != QColor(m_property->qtActiveColor) && m_xSetting) {
         m_property->qtActiveColor = result;
-        updateCustomTheme(TYPEACTIVECOLOR, result);
+        updateCustomTheme(TYPEACTIVECOLOR, activeColors);
     }
 }
 
@@ -1151,11 +1164,22 @@ bool AppearanceManager::doSetGlobalTheme(QString value)
     KeyFile theme(',');
     theme.loadFile(themePath + "/index.theme");
     QString defaultTheme = theme.getStr("Deepin Theme", "DefaultTheme");
-    if (defaultTheme.isEmpty())
+    QString lightActiveColor;
+    if (defaultTheme.isEmpty()) {
         return false;
+    } else {
+        lightActiveColor = theme.getStr(defaultTheme, "ActiveColor");
+    }
+
     QString darkTheme = theme.getStr("Deepin Theme", "DarkTheme");
-    if (darkTheme.isEmpty())
+    QString darkActiveColor;
+    if (darkTheme.isEmpty()) {
         mode = Light;
+    } else {
+        darkActiveColor = theme.getStr(darkTheme, "ActiveColor", lightActiveColor);
+    }
+
+    setActiveColors(lightActiveColor + "," + darkActiveColor);
 
     m_currentGlobalTheme = value;
     switch (mode) {
@@ -1664,7 +1688,10 @@ void AppearanceManager::applyGlobalTheme(KeyFile &theme, const QString &themeNam
 
     // 如果是用户自定义主题, 切换外观时只单独更新外观选项
     if (themePath.endsWith("custom")) {
-        return setGlobalItem("AppTheme", TYPEGTK);
+        setGlobalItem("AppTheme", TYPEGTK);
+        setGlobalItem("ActiveColor", TYPEACTIVECOLOR);
+        m_globalThemeUpdating = false;
+        return;
     }
 
     setGlobalFile("Wallpaper", TYPEWALLPAPER);
