@@ -31,6 +31,7 @@ const QString APPEARANCE_INTERFACE = "org.deepin.dde.Appearance1";
 #define GSKEYFONTMONOSPACE       "Font_Monospace"
 #define GSKEYOPACITY             "Opacity"
 #define GSKEYQTACTIVECOLOR       "qtActiveColor"
+#define GSKEYQTACTIVECOLOR_DARK  "qtDarkActiveColor"
 #define GSKEYFONTSTANDARD        "Font_Standard"
 #define GSKEYWALLPAPERSLIDESHOW  "Wallpaper_Slideshow"
 #define GSKEYWALLPAPERURIS       "Wallpaper_Uris"
@@ -38,6 +39,7 @@ const QString APPEARANCE_INTERFACE = "org.deepin.dde.Appearance1";
 #define GSKEYFONTNAME            "gtkFontName"
 #define DCKEYALLWALLPAPER        "All_Wallpaper_Uris"
 #define DDTKSIZEMODE             "Dtk_Size_Mode"
+#define DACTIVECOLORS            "Active_Colors"
 
 #define GTK2CONFDELIM            "="
 #define GTK3GROUPSETTINGS        "Settings"
